@@ -30,4 +30,14 @@ decode_dict = {
     '@': '%40',
     '\\': '%5C',
     '|': '%7C',
-}
\ No newline at end of file
+}
+
+default_settings = {
+    'save_to' : None,
+    'file_name' : None,
+    'quality' : None,
+    'index' : None,
+    'dl_range' : (),
+    'dl_list' : [], 
+    'retries' : 2,
+    }
\ No newline at end of file
